@@ -6,6 +6,11 @@ from bcmr.models import *
 admin.site.site_header = 'Django BCMR Admin'
 
 
+class AuthTokenAdmin(admin.ModelAdmin):
+    list_display = [
+        'id',
+    ]
+
 class TokenAdmin(admin.ModelAdmin):
     list_display = [
         'category',
@@ -25,5 +30,6 @@ class RegistryAdmin(admin.ModelAdmin):
     ]
 
 
+admin.site.register(AuthToken, AuthTokenAdmin)
 admin.site.register(Token, TokenAdmin)
 admin.site.register(Registry, RegistryAdmin)
