@@ -1,6 +1,12 @@
 from django.utils import timezone
 from django.db import models
 
+import uuid
+
+
+class AuthToken(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
+    
 
 class Token(models.Model):
     class Status(models.TextChoices):
@@ -20,6 +26,13 @@ class Token(models.Model):
         choices=Status.choices,
         default=Status.ACTIVE
     )
+    owner = models.ForeignKey(
+        AuthToken,
+        related_name='tokens',
+        on_delete=models.PROTECT,
+        null=True,
+        blank=True
+    )
 
     class Meta:
         ordering = ('name', )
@@ -34,6 +47,13 @@ class Registry(models.Model):
     date_created = models.DateTimeField(default=timezone.now)
     latest_revision = models.DateTimeField(default=timezone.now)
     tokens = models.ManyToManyField(Token)
+    owner = models.ForeignKey(
+        AuthToken,
+        related_name='registries',
+        on_delete=models.PROTECT,
+        null=True,
+        blank=True
+    )
 
     class Meta:
         verbose_name_plural = 'Registries'
